@@ -2722,7 +2722,10 @@ SendCommandResultTypeDef = TypedDict(
 
 SessionFilterTypeDef = TypedDict(
     "SessionFilterTypeDef",
-    {"key": Literal["InvokedAfter", "InvokedBefore", "Target", "Owner", "Status"], "value": str},
+    {
+        "key": Literal["InvokedAfter", "InvokedBefore", "Target", "Owner", "Status", "SessionId"],
+        "value": str,
+    },
 )
 
 StartAutomationExecutionResultTypeDef = TypedDict(
